pub struct EditError { /* private fields */ }Expand description
A fail-closed validation or application error.
Implementations
Sourceimpl EditError
impl EditError
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Human-readable diagnostic. Consumers should branch on Self::code.
Sourcepub const fn file_index(&self) -> Option<usize>
pub const fn file_index(&self) -> Option<usize>
File index within the plan, when applicable.
Sourcepub const fn edit_index(&self) -> Option<usize>
pub const fn edit_index(&self) -> Option<usize>
Edit index within the file or input slice, when applicable.
The other edit participating in an overlap, when applicable.
Sourcepub fn mismatch(&self) -> Option<&MismatchDetails>
pub fn mismatch(&self) -> Option<&MismatchDetails>
Bounded expected/actual evidence for ErrorCode::BeforeMismatch.