pub struct PreparedChange<'change> {
pub source_range: Range<usize>,
pub output_range: Range<usize>,
pub before: &'change str,
pub after: &'change str,
pub input_order: usize,
/* private fields */
}Expand description
One normalized edit with exact source and resulting byte ranges.
Fields
source_range: Range<usize>output_range: Range<usize>before: &'change strafter: &'change strinput_order: usizeImplementations
Sourceimpl PreparedChange<'_>
impl PreparedChange<'_>
Sourcepub fn provenance(&self) -> &Provenance
pub fn provenance(&self) -> &Provenance
Primary provenance retained from the first equivalent prepared edit.
Sourcepub fn provenances(&self) -> impl Iterator<Item = &Provenance>
pub fn provenances(&self) -> impl Iterator<Item = &Provenance>
Every distinct provenance retained across equivalent unioned edits.
pub fn provenance_count(&self) -> usize