pub struct ValidationReport { /* private fields */ }Expand description
Bounded result of checking a complete edit set without applying it.
Implementations
Sourceimpl ValidationReport
impl ValidationReport
Sourcepub const fn is_valid(&self) -> bool
pub const fn is_valid(&self) -> bool
Returns true when the full checked set had no validation failures.
Sourcepub fn diagnostics(&self) -> &[EditError]
pub fn diagnostics(&self) -> &[EditError]
Diagnostics retained under DiagnosticLimits::max_items.
Sourcepub const fn total_diagnostics(&self) -> usize
pub const fn total_diagnostics(&self) -> usize
Total failures observed, including omitted diagnostics.
Sourcepub const fn is_truncated(&self) -> bool
pub const fn is_truncated(&self) -> bool
Returns true when some observed diagnostics were omitted.